Description Usage Arguments Value
Takes a random sample from df of size sample_size.
1 | sample_data(df, sample_size)
|
df |
|
sample_size |
|
data.frame with samples from df or df if sample_size
is NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.